@@ -27,6 +27,8 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <sys/stat.h>
+#include <assert.h>
+#include <uuid/uuid.h>
 
 #include "types.h"
 #include "inventory_priv.h"
@@ -41,67 +43,67 @@ int sesslock_fd = -1;
 /*----------------------------------------------------------------------*/
 
 inv_idbtoken_t
-inv_open( inv_predicate_t bywhat, void *pred )
+inv_open(inv_predicate_t bywhat, void *pred)
 {
 
 	int fd, stobjfd, num;
-	char uuname[ INV_STRLEN ];
+	char uuname[INV_STRLEN];
 	inv_idbtoken_t tok = INV_TOKEN_NULL;
 	invt_sescounter_t *sescnt = 0;
-	
+
 	int index = 0;
-	
-	ASSERT ( pred );
-	if ((fd = init_idb ( pred, bywhat, uuname, &tok )) < 0 )
+
+	assert (pred);
+	if ((fd = init_idb (pred, bywhat, uuname, &tok)) < 0)
 		return tok;
 
 	/* XXX also, see if it is too full. if so, make another and leave a
 	   reference to the new file in the old one */
 
-	stobjfd = get_storageobj( fd, &index );
-	if ( stobjfd < 0 ) {
-		close( fd );
-		close( sesslock_fd );
+	stobjfd = get_storageobj(fd, &index);
+	if (stobjfd < 0) {
+		close(fd);
+		close(sesslock_fd);
 		sesslock_fd = -1;
 		return INV_TOKEN_NULL;
 	}
 
-	ASSERT ( index > 0 );
+	assert (index > 0);
 
 	/* Now we need to make sure that this has enough space */
-	num = GET_SESCOUNTERS( stobjfd, &sescnt );
-	if ( num < 0 ) {
-		close( fd );
-		close( stobjfd );
-		close( sesslock_fd );
+	num = GET_SESCOUNTERS(stobjfd, &sescnt);
+	if (num < 0) {
+		close(fd);
+		close(stobjfd);
+		close(sesslock_fd);
 		sesslock_fd = -1;
 		return INV_TOKEN_NULL;
 	}
-	/* create another storage object ( and, an inv_index entry for it too )
+	/* create another storage object (and, an inv_index entry for it too)
 	   if we've filled this one up */
-	if ( (u_int) num >= sescnt->ic_maxnum ) {
+	if ((uint) num >= sescnt->ic_maxnum) {
 #ifdef INVT_DEBUG
-		printf("$ creating a new storage obj & index entry. \n" );
+		printf("$ creating a new storage obj & index entry. \n");
 #endif
 		close (stobjfd);
-		
-		stobjfd = create_invindex_entry( &tok, fd, uuname, BOOL_FALSE );
-		free ( sescnt );		
-		if ( stobjfd < 0 ) {
-			close( fd );
-			close( sesslock_fd );
+
+		stobjfd = create_invindex_entry(&tok, fd, uuname, BOOL_FALSE);
+		free (sescnt);
+		if (stobjfd < 0) {
+			close(fd);
+			close(sesslock_fd);
 			sesslock_fd = -1;
 			return INV_TOKEN_NULL;
 		}
 		return tok;
 	}
-	
-	free ( sescnt );
-	tok = get_token( fd, stobjfd );
-	tok->d_invindex_off = INVINDEX_HDR_OFFSET( index - 1 );
-	
+
+	free (sescnt);
+	tok = get_token(fd, stobjfd);
+	tok->d_invindex_off = INVINDEX_HDR_OFFSET(index - 1);
+
 	return tok;
-	
+
 }
 
 
@@ -115,14 +117,14 @@ inv_open( inv_predicate_t bywhat, void *pred )
 
 
 bool_t
-inv_close( inv_idbtoken_t tok )
+inv_close(inv_idbtoken_t tok)
 {
-	close ( tok->d_invindex_fd );
-	close ( tok->d_stobj_fd );
-	destroy_token( tok );
-	close( sesslock_fd );
+	close (tok->d_invindex_fd);
+	close (tok->d_stobj_fd);
+	destroy_token(tok);
+	close(sesslock_fd);
 	sesslock_fd = -1;
-	
+
 	return BOOL_TRUE;
 }
 
@@ -139,18 +141,18 @@ inv_close( inv_idbtoken_t tok )
 /*----------------------------------------------------------------------*/
 
 bool_t
-inv_lasttime_level_lessthan( 
+inv_lasttime_level_lessthan(
 	inv_idbtoken_t  tok,
 	u_char level,
-	time32_t **tm )
+	time32_t **tm)
 {
 	int 	rval;
-	ASSERT ( tok != INV_TOKEN_NULL );
+	assert (tok != INV_TOKEN_NULL);
 
-	rval =  search_invt( tok, level, (void **) tm,
-			 (search_callback_t) tm_level_lessthan );
+	rval =  search_invt(tok, level, (void **) tm,
+			 (search_callback_t) tm_level_lessthan);
 
-	return ( rval < 0) ? BOOL_FALSE: BOOL_TRUE;
+	return (rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 }
 
 
@@ -164,18 +166,18 @@ inv_lasttime_level_lessthan(
 /*----------------------------------------------------------------------*/
 
 bool_t
-inv_lastsession_level_lessthan( 
+inv_lastsession_level_lessthan(
 	inv_idbtoken_t 	tok,
 	u_char		level,
-	inv_session_t 	**ses )
+	inv_session_t 	**ses)
 {
 	int 	rval;
-	ASSERT ( tok != INV_TOKEN_NULL );
+	assert (tok != INV_TOKEN_NULL);
 
-	rval = search_invt( tok, level, (void **) ses, 
-			  (search_callback_t) lastsess_level_lessthan );
+	rval = search_invt(tok, level, (void **) ses,
+			  (search_callback_t) lastsess_level_lessthan);
 
-	return ( rval < 0) ? BOOL_FALSE: BOOL_TRUE;
+	return (rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 
 }
 
@@ -191,17 +193,17 @@ inv_lastsession_level_lessthan(
 
 
 bool_t
-inv_lastsession_level_equalto( 
-	inv_idbtoken_t 	tok,			    
+inv_lastsession_level_equalto(
+	inv_idbtoken_t 	tok,
 	u_char		level,
-	inv_session_t	**ses )
+	inv_session_t	**ses)
 {
 	int 	rval;
-	ASSERT ( tok != INV_TOKEN_NULL );
-	rval = search_invt( tok, level, (void **) ses, 
-			  (search_callback_t) lastsess_level_equalto );
+	assert (tok != INV_TOKEN_NULL);
+	rval = search_invt(tok, level, (void **) ses,
+			  (search_callback_t) lastsess_level_equalto);
 
-	return ( rval < 0) ? BOOL_FALSE: BOOL_TRUE;
+	return (rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 
 }
 
@@ -218,29 +220,29 @@ inv_lastsession_level_equalto(
 /*----------------------------------------------------------------------*/
 
 inv_sestoken_t
-inv_writesession_open( 
+inv_writesession_open(
 	inv_idbtoken_t tok, 	/* token obtained by inventory_open() */
 	uuid_t		*fsid,
 	uuid_t		*sesid,
 	char		*label,
 	u_char		level,
-	u_int		nstreams,
+	uint		nstreams,
 	time32_t	time,
 	char		*mntpt,
-	char		*devpath )
+	char		*devpath)
 {
 	invt_session_t *ses;
 	int		fd;
-	intgen_t	rval;
+	int	rval;
 	invt_sescounter_t *sescnt = NULL;
 	invt_seshdr_t  	hdr;
 	inv_sestoken_t	sestok;
 
-	ASSERT ( tok != INV_TOKEN_NULL );
-	ASSERT ( sesid && fsid && mntpt && devpath );
+	assert (tok != INV_TOKEN_NULL);
+	assert (sesid && fsid && mntpt && devpath);
 
-	if ( ! ( tok->d_update_flag & FSTAB_UPDATED ) ) {
-		if ( put_fstab_entry( fsid, mntpt, devpath ) < 0 ) {
+	if (!(tok->d_update_flag & FSTAB_UPDATED)) {
+		if (put_fstab_entry(fsid, mntpt, devpath) < 0) {
 			printf ("put_fstab_entry :(\n");
 			return INV_TOKEN_NULL;
 		}
@@ -249,63 +251,63 @@ inv_writesession_open(
 
 
 
-	ses = (invt_session_t *) calloc( 1, sizeof( invt_session_t ) );
+	ses = (invt_session_t *) calloc(1, sizeof(invt_session_t));
 
 	/* copy the session information to store */
-	memcpy( &ses->s_sesid, sesid, sizeof( uuid_t ) );
-	memcpy( &ses->s_fsid, fsid, sizeof( uuid_t ) );
-	strcpy( ses->s_label, label );	
-	strcpy( ses->s_mountpt, mntpt );	
-	strcpy( ses->s_devpath, devpath );	
+	memcpy(&ses->s_sesid, sesid, sizeof(uuid_t));
+	memcpy(&ses->s_fsid, fsid, sizeof(uuid_t));
+	strcpy(ses->s_label, label);
+	strcpy(ses->s_mountpt, mntpt);
+	strcpy(ses->s_devpath, devpath);
 	ses->s_max_nstreams = nstreams;
 
 
 	/* s_curstream_off will be set in create_session() */
 
 	fd = tok->d_stobj_fd;
-	
-	ASSERT ( fd > 0 );
+
+	assert (fd > 0);
 
 	hdr.sh_time = time;
-	hdr.sh_level = level;	
+	hdr.sh_level = level;
 	/* sh_streams_off and sh_sess_off will be set in create_session() */
-	
-	sestok = get_sesstoken( tok );
 
-	/* we need to put the new session in the appropriate place in 
+	sestok = get_sesstoken(tok);
+
+	/* we need to put the new session in the appropriate place in
 	   storage object. So first find out howmany sessions are there */
 
-	INVLOCK( fd, LOCK_EX );
-	if ( GET_SESCOUNTERS( fd, &sescnt) < 0 ) {
-		free ( ses );
-		free ( sestok );
-		INVLOCK( fd, LOCK_UN );
+	INVLOCK(fd, LOCK_EX);
+	if (GET_SESCOUNTERS(fd, &sescnt) < 0) {
+		free (ses);
+		free (sestok);
+		INVLOCK(fd, LOCK_UN);
 		return INV_TOKEN_NULL;
 	}
 
-	/* create the writesession, and get ready for the streams to come 
+	/* create the writesession, and get ready for the streams to come
 	   afterwards */
-	rval = create_session( sestok, fd, sescnt, ses, &hdr );
-	ASSERT (rval > 0);
+	rval = create_session(sestok, fd, sescnt, ses, &hdr);
+	assert (rval > 0);
 
 
-	INVLOCK( fd, LOCK_UN );
- 
+	INVLOCK(fd, LOCK_UN);
+
 	sestok->sd_sesstime = time;
 
-	if ( tok->d_update_flag & NEW_INVINDEX ) {
-		if ( put_sesstime( sestok, INVT_STARTTIME ) < 0 ) {
+	if (tok->d_update_flag & NEW_INVINDEX) {
+		if (put_sesstime(sestok, INVT_STARTTIME) < 0) {
 			printf ("put_starttime :(\n");
 			return INV_TOKEN_NULL;
 		}
 		tok->d_update_flag &= ~(NEW_INVINDEX);
 	}
 
-	free ( ses );
-	free ( sescnt );
+	free (ses);
+	free (sescnt);
 
 
-	return ( rval < 0 )? INV_TOKEN_NULL: sestok;
+	return (rval < 0)? INV_TOKEN_NULL: sestok;
 }
 
 
@@ -320,20 +322,20 @@ inv_writesession_open(
 
 
 bool_t
-inv_writesession_close( inv_sestoken_t tok )
+inv_writesession_close(inv_sestoken_t tok)
 {
 	int		rval;
-	
-	ASSERT ( tok != INV_TOKEN_NULL );
+
+	assert (tok != INV_TOKEN_NULL);
 
 	/* now update end_time in the inv index header */
-	rval = put_sesstime( tok, INVT_ENDTIME );
+	rval = put_sesstime(tok, INVT_ENDTIME);
 
-	memset( tok, 0, sizeof( invt_sesdesc_entry_t ) );
+	memset(tok, 0, sizeof(invt_sesdesc_entry_t));
 
-	free ( tok );
+	free (tok);
 
-	return ( rval < 0 ) ? BOOL_FALSE: BOOL_TRUE;
+	return (rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 
 }
 
@@ -346,7 +348,7 @@ inv_writesession_close( inv_sestoken_t tok )
 /*----------------------------------------------------------------------*/
 inv_stmtoken_t
 inv_stream_open(
-	inv_sestoken_t tok )
+	inv_sestoken_t tok)
 {
 	inv_stmtoken_t stok;
 	invt_stream_t  stream;
@@ -354,29 +356,29 @@ inv_stream_open(
 	invt_seshdr_t  seshdr;
 	int fd;
 
-	ASSERT ( tok != INV_TOKEN_NULL );
-	 
+	assert (tok != INV_TOKEN_NULL);
+
 	stream.st_nmediafiles = 0;
 	stream.st_interrupted = BOOL_FALSE;
 
-	
+
 	/* XXX yukk... make the token descriptors not pointers */
-	stok = ( inv_stmtoken_t ) malloc( sizeof( invt_strdesc_entry_t ) );
-	
+	stok = (inv_stmtoken_t) malloc(sizeof(invt_strdesc_entry_t));
+
 	stok->md_sesstok = tok;
 	stok->md_lastmfile = 0;
-	
+
 	/* get the session to find out where the stream is going to go */
-	fd = tok->sd_invtok->d_stobj_fd; 
+	fd = tok->sd_invtok->d_stobj_fd;
 
 	sess_lock();
-	
-	INVLOCK( fd, LOCK_SH );
+
+	INVLOCK(fd, LOCK_SH);
 	/* get the session header first */
-	if ( GET_REC_NOLOCK( fd, &seshdr, sizeof( invt_seshdr_t ),
-			     tok->sd_sesshdr_off ) <= 0 ) {
-		free ( stok );
-		INVLOCK( fd, LOCK_UN );
+	if (GET_REC_NOLOCK(fd, &seshdr, sizeof(invt_seshdr_t),
+			     tok->sd_sesshdr_off) <= 0) {
+		free (stok);
+		INVLOCK(fd, LOCK_UN);
 		sess_unlock();
 		return INV_TOKEN_NULL;
 	}
@@ -384,44 +386,44 @@ inv_stream_open(
 
 
 	/* XXX Have one func that gives both seshdr and session */
-	if ( GET_REC_NOLOCK( fd, &ses, sizeof( invt_session_t ),
-			     tok->sd_session_off ) <= 0 ) {
-		free ( stok );
-		INVLOCK( fd, LOCK_UN );
+	if (GET_REC_NOLOCK(fd, &ses, sizeof(invt_session_t),
+			     tok->sd_session_off) <= 0) {
+		free (stok);
+		INVLOCK(fd, LOCK_UN);
 		sess_unlock();
 		return INV_TOKEN_NULL;
 	}
-	INVLOCK( fd, LOCK_UN );
+	INVLOCK(fd, LOCK_UN);
 
-	if ( ses.s_cur_nstreams < ses.s_max_nstreams ) {
+	if (ses.s_cur_nstreams < ses.s_max_nstreams) {
 		/* this is where this stream header will be written to */
-		stok->md_stream_off = (off64_t) (sizeof( invt_stream_t ) * 
-					         ses.s_cur_nstreams )
+		stok->md_stream_off = (off64_t) (sizeof(invt_stream_t) *
+					         ses.s_cur_nstreams)
 			                         + seshdr.sh_streams_off;
 		ses.s_cur_nstreams++;
-				
+
 		/* write it back. this locks and unlocks fd EXclusively */
-		if ( PUT_REC( fd, &ses, sizeof( ses ), 
-			      tok->sd_session_off ) < 0 ) {
-			free ( stok );
+		if (PUT_REC(fd, &ses, sizeof(ses),
+			      tok->sd_session_off) < 0) {
+			free (stok);
 			sess_unlock();
 			return INV_TOKEN_NULL;
 		}
 	} else {
 		fprintf(stderr, "Cant create more than %d streams. Max'd out..\n",
-			ses.s_cur_nstreams );
-		free ( stok );
+			ses.s_cur_nstreams);
+		free (stok);
 		sess_unlock();
 		return INV_TOKEN_NULL;
 	}
 	sess_unlock();
 
 	stream.st_firstmfile = stream.st_lastmfile = stok->md_stream_off;
-	
+
 	/* now put the stream header on to the disk */
-	if ( PUT_REC( fd, &stream, sizeof( invt_stream_t ),
-		      stok->md_stream_off ) < 0 ) {
-		free ( stok );
+	if (PUT_REC(fd, &stream, sizeof(invt_stream_t),
+		      stok->md_stream_off) < 0) {
+		free (stok);
 		return INV_TOKEN_NULL;
 	}
 
@@ -440,48 +442,48 @@ inv_stream_open(
 bool_t
 inv_stream_close(
 		inv_stmtoken_t	tok,
-		bool_t wasinterrupted )
+		bool_t wasinterrupted)
 {
 	invt_stream_t strm;
 	int fd = tok->md_sesstok->sd_invtok->d_stobj_fd;
 	int rval;
 	bool_t dowrite = BOOL_FALSE;
 
-	INVLOCK( fd, LOCK_EX );
-	if ((rval = GET_REC_NOLOCK( fd, &strm, sizeof( invt_stream_t ), 
-			       tok->md_stream_off )) < 0 )
+	INVLOCK(fd, LOCK_EX);
+	if ((rval = GET_REC_NOLOCK(fd, &strm, sizeof(invt_stream_t),
+			       tok->md_stream_off)) < 0)
 		goto end;   /* eek :-)   */
-	
-	if ( strm.st_interrupted != wasinterrupted ) {
+
+	if (strm.st_interrupted != wasinterrupted) {
 		strm.st_interrupted = wasinterrupted;
 		dowrite = BOOL_TRUE;
 	}
 
-	/* get the last media file to figure out what our last ino was. 
+	/* get the last media file to figure out what our last ino was.
 	   we have a pointer to that in the stream token */
-	if ( tok->md_lastmfile ){
-		if ( strm.st_endino.ino != tok->md_lastmfile->mf_endino.ino ||
+	if (tok->md_lastmfile){
+		if (strm.st_endino.ino != tok->md_lastmfile->mf_endino.ino ||
 		     strm.st_endino.offset != tok->md_lastmfile->mf_endino.offset){
 			printf("Warning: endinos dont match ! \n");
 			dowrite = BOOL_TRUE;
 			strm.st_endino = tok->md_lastmfile->mf_endino;
 		}
 	}
-			
+
 	if (dowrite) {
-		rval = PUT_REC_NOLOCK_SEEKCUR( fd, &strm, sizeof( invt_stream_t ),
-					       (off64_t) -(sizeof( invt_stream_t )) );
+		rval = PUT_REC_NOLOCK(fd, &strm, sizeof(invt_stream_t),
+				      tok->md_stream_off);
 	}
  end:
-	INVLOCK( fd, LOCK_UN );
+	INVLOCK(fd, LOCK_UN);
 
-	free ( tok->md_lastmfile );
-	memset( tok, 0, sizeof( invt_strdesc_entry_t ) );
-	free ( tok );
+	free (tok->md_lastmfile);
+	memset(tok, 0, sizeof(invt_strdesc_entry_t));
+	free (tok);
 
-	return ( rval < 0 ) ? BOOL_FALSE: BOOL_TRUE;
+	return (rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 }
- 
+
 
 
 
@@ -492,43 +494,43 @@ inv_stream_close(
 /*----------------------------------------------------------------------*/
 
 bool_t
-inv_put_mediafile( 
-	inv_stmtoken_t 	tok, 
-	uuid_t 		*moid, 
+inv_put_mediafile(
+	inv_stmtoken_t 	tok,
+	uuid_t 		*moid,
 	char 		*label,
 	xfs_ino_t	startino,
 	off64_t		startino_offset,
 	xfs_ino_t	endino,
-	off64_t		endino_offset )
+	off64_t		endino_offset)
 {
 	invt_mediafile_t *mf;
 	int 		 rval;
 
 
-	ASSERT ( tok != INV_TOKEN_NULL );
-	ASSERT ( tok->md_sesstok->sd_invtok->d_update_flag & FSTAB_UPDATED );
-	ASSERT ( tok->md_sesstok->sd_invtok->d_stobj_fd >= 0 );
+	assert (tok != INV_TOKEN_NULL);
+	assert (tok->md_sesstok->sd_invtok->d_update_flag & FSTAB_UPDATED);
+	assert (tok->md_sesstok->sd_invtok->d_stobj_fd >= 0);
+
+	mf = (invt_mediafile_t *) calloc(1, sizeof(invt_mediafile_t));
 
-	mf = (invt_mediafile_t *) calloc( 1, sizeof( invt_mediafile_t ) );
-	
 	/* copy the media file information */
-	memcpy( &mf->mf_moid, moid, sizeof( uuid_t ) );
-	strcpy( mf->mf_label, label );	
+	memcpy(&mf->mf_moid, moid, sizeof(uuid_t));
+	strcpy(mf->mf_label, label);
 	mf->mf_startino.ino = startino;
 	mf->mf_startino.offset = startino_offset;
 	mf->mf_endino.ino = endino;
 	mf->mf_endino.offset = endino_offset;
-	
-	INVLOCK( tok->md_sesstok->sd_invtok->d_stobj_fd, LOCK_EX );
-	rval = put_mediafile( tok, mf );
-	INVLOCK( tok->md_sesstok->sd_invtok->d_stobj_fd, LOCK_UN );
+
+	INVLOCK(tok->md_sesstok->sd_invtok->d_stobj_fd, LOCK_EX);
+	rval = put_mediafile(tok, mf);
+	INVLOCK(tok->md_sesstok->sd_invtok->d_stobj_fd, LOCK_UN);
 
 	/* we dont free the mfile here. we always keep the last mfile
 	   around, inside the inv_stmtoken, and when we add a new mfile,
 	   we free the previous one. The last one is freed in stream_close()
 	   */
 
-	return ( rval < 0 ) ? BOOL_FALSE: BOOL_TRUE;
+	return (rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 
 }
 
@@ -541,68 +543,68 @@ inv_put_mediafile(
 /* that the client (dump) knows that these shouldn't be dumped alongwith*/
 /* regular files.                                                       */
 /*                                                                      */
-/* foreach ( fs in fstab )                                              */
-/* 	foreach ( index in InvIndex )                                 */
+/* foreach (fs in fstab)                                              */
+/* 	foreach (index in InvIndex)                                 */
 /*          get                                                         */
 /*----------------------------------------------------------------------*/
 
-intgen_t
+int
 inv_get_inolist(
-	inv_inolist_t 	**inolist )
+	inv_inolist_t 	**inolist)
 {
 	invt_entry_t	*iarr = NULL;
 	invt_counter_t	*icnt = NULL;
 	int	     	nindices, i;
-	struct stat64	statbuf;	
+	struct stat64	statbuf;
 	inv_inolist_t 	*curitem;
 
-#ifdef NOTDEF	
+#ifdef NOTDEF
 	*inolist = NULL;
-	curitem = malloc( sizeof( inv_inolist_t ) );
-	
+	curitem = malloc(sizeof(inv_inolist_t));
+
 	/* get the array of all indices in the invindex */
-	if ( ( nindices = GET_ALLHDRS_N_CNTS( invfd, (void **)&iarr, 
-					      (void **)&icnt, 
-					      sizeof( invt_entry_t ),
-					      sizeof( invt_counter_t )) 
-	      ) <= 0 ) {
+	if ((nindices = GET_ALLHDRS_N_CNTS(invfd, (void **)&iarr,
+					      (void **)&icnt,
+					      sizeof(invt_entry_t),
+					      sizeof(invt_counter_t))
+	      ) <= 0) {
 		return -1;
 	}
-	free( icnt );
-	
+	free(icnt);
+
 	/* attach all the StObjs */
 	for (i = nindices - 1; i >= 0; i--) {
-		if ( stat64( iarr[i].ie_filename, &statbuf ) < 0 ) {
-			perror( iarr[i].ie_filename );
+		if (stat64(iarr[i].ie_filename, &statbuf) < 0) {
+			perror(iarr[i].ie_filename);
 			return -1;
 		}
-		
-		create_inolist_item( curitem, statbuf.st_ino );
+
+		create_inolist_item(curitem, statbuf.st_ino);
 	}
 	/* The inventory index */
-	if ( fstat64( invfd, &statbuf ) ){
-		perror( "InvIndex file" );
+	if (fstat64(invfd, &statbuf)){
+		perror("InvIndex file");
 		return -1;
 	}
-	create_inolist_item( curitem, statbuf.st_ino );
+	create_inolist_item(curitem, statbuf.st_ino);
 
 	/* fstab */
-	if ( stat64( INV_FSTAB, &statbuf ) < 0 ) {
-			perror( INV_FSTAB );
+	if (stat64(INV_FSTAB, &statbuf) < 0) {
+			perror(INV_FSTAB);
 			return -1;
 		}
-	create_inolist_item( curitem, statbuf.st_ino );
-	
+	create_inolist_item(curitem, statbuf.st_ino);
+
 	/* sesslock file */
-	if ( stat64( SESSLOCK_FILE, &statbuf ) < 0 ) {
-			perror( SESSLOCK_FILE );
+	if (stat64(SESSLOCK_FILE, &statbuf) < 0) {
+			perror(SESSLOCK_FILE);
 			return -1;
 		}
-	create_inolist_item( curitem, statbuf.st_ino );
+	create_inolist_item(curitem, statbuf.st_ino);
 #endif
 
 	return 1;
-		
+
 }
 
 
@@ -625,14 +627,14 @@ bool_t
 inv_get_session(
 	inv_sestoken_t		tok,
 	void		      **bufpp,	/* buf to fill */
-	size_t		       *bufszp )/* size of that buffer */
+	size_t		       *bufszp)/* size of that buffer */
 {
-	ASSERT( tok != INV_TOKEN_NULL );
-	ASSERT( tok->sd_invtok );
+	assert(tok != INV_TOKEN_NULL);
+	assert(tok->sd_invtok);
 
 	/* First get the session header, and the session information. Then
 	   we can figure out how much space to allocate */
-	
+
 }
 
 
@@ -642,15 +644,15 @@ inv_get_session(
 
 /* This prints out all the sessions of a filesystem that are in the inventory */
 bool_t
-inv_DEBUG_printallsessions( 
-	inv_idbtoken_t 	tok,			    
-	inv_session_t	**ses )
+inv_DEBUG_printallsessions(
+	inv_idbtoken_t 	tok,
+	inv_session_t	**ses)
 {
 	int 	rval;
-	rval = search_invt( tok, 0, (void **) ses, 
-			  (search_callback_t) DEBUG_displayallsessions );
+	rval = search_invt(tok, 0, (void **) ses,
+			  (search_callback_t) DEBUG_displayallsessions);
 
-	return ( rval < 0) ? BOOL_FALSE: BOOL_TRUE;
+	return (rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 
 }
 
